# Тестовый пакет

Включает в себя игру Астероид 1.0.
Ссылка на GitHub:
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)

Проект создавался для обучения программированию.
